@@ -3,7 +3,7 @@ package Log::ger::Output::Callback;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-03-09'; # DATE
 our $DIST = 'Log-ger-Output-Callback'; # DIST
-our $VERSION = '0.007'; # VERSION
+our $VERSION = '0.008'; # VERSION
 
 use 5.010001;
 use strict;
@@ -29,7 +29,7 @@ sub get_hooks {
                 my %hook_args = @_; # see Log::ger::Manual::Internals/"Arguments passed to hook"
                 my $outputter = sub {
                     my ($per_target_conf, $msg, $per_msg_conf) = @_;
-                    my $level = $per_msg_conf->{level} // $hook_args{level};
+                    my $level = $per_msg_conf ? $per_msg_conf->{level} : undef; $level = $hook_args{level} if !defined $level;
                     $plugin_conf{logging_cb}->($per_target_conf, $level, $msg, $per_msg_conf);
                 };
                 [$outputter];
@@ -69,7 +69,7 @@ Log::ger::Output::Callback - Send logs to a subroutine
 
 =head1 VERSION
 
-This document describes version 0.007 of Log::ger::Output::Callback (from Perl distribution Log-ger-Output-Callback), released on 2020-03-09.
+This document describes version 0.008 of Log::ger::Output::Callback (from Perl distribution Log-ger-Output-Callback), released on 2020-03-09.
 
 =head1 SYNOPSIS
 
